@@ -1,15 +1,18 @@
 /*
- Copyright 2021 The GoPlus Authors (goplus.org)
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-     http://www.apache.org/licenses/LICENSE-2.0
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-*/
+ * Copyright (c) 2021 The GoPlus Authors (goplus.org). All rights reserved.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package builtin
 
@@ -184,6 +187,11 @@ func (a Gop_bigint) Gop_Neg() Gop_bigint {
 	return Gop_bigint{tmpint1(a).Neg(a.Int)}
 }
 
+// Gop_Pos: func +(a bigint) bigint
+func (a Gop_bigint) Gop_Pos() Gop_bigint {
+	return a
+}
+
 // Gop_Not: func ^(a bigint) bigint
 func (a Gop_bigint) Gop_Not() Gop_bigint {
 	return Gop_bigint{tmpint1(a).Not(a.Int)}
@@ -395,6 +403,11 @@ func (a Gop_bigrat) Gop_Neg() Gop_bigrat {
 	return Gop_bigrat{tmprat1(a).Neg(a.Rat)}
 }
 
+// Gop_Pos: func +(a bigrat) bigrat
+func (a Gop_bigrat) Gop_Pos() Gop_bigrat {
+	return a
+}
+
 // Gop_Inv: func /(a bigrat) bigrat
 func (a Gop_bigrat) Gop_Inv() Gop_bigrat {
 	return Gop_bigrat{tmprat1(a).Inv(a.Rat)}
