@@ -25,11 +25,12 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/qiniu/x/log"
+
 	"github.com/goplus/gop/ast"
 	"github.com/goplus/gop/parser/parsertest"
 	"github.com/goplus/gop/scanner"
 	"github.com/goplus/gop/token"
-	"github.com/qiniu/x/log"
 )
 
 // -----------------------------------------------------------------------------
@@ -53,10 +54,10 @@ func TestReadSource(t *testing.T) {
 	}
 }
 
-func TestParseFile(t *testing.T) {
+func TestParseFiles(t *testing.T) {
 	fset := token.NewFileSet()
-	if _, err := ParseFile(fset, "/foo/bar/not-exists", nil, PackageClauseOnly); err == nil {
-		t.Fatal("ParseFile failed: no error?")
+	if _, err := ParseFiles(fset, []string{"/foo/bar/not-exists"}, PackageClauseOnly); err == nil {
+		t.Fatal("ParseFiles failed: no error?")
 	}
 }
 
@@ -119,6 +120,17 @@ func TestParseGo(t *testing.T) {
 	}
 }
 
+func TestParseGoFiles(t *testing.T) {
+	fset := token.NewFileSet()
+	pkgs, err := ParseFiles(fset, []string{"./_testdata/functype/functype.go"}, Trace)
+	if err != nil {
+		t.Fatal("TestParseGoFiles: ParseFiles failed -", err)
+	}
+	if len(pkgs) != 1 {
+		t.Fatal("TestParseGoFiles failed: len(pkgs) =", len(pkgs))
+	}
+}
+
 func TestFromTestdata(t *testing.T) {
 	sel := ""
 	dir, err := os.Getwd()
