@@ -707,6 +707,54 @@ var addGoTests = []struct {
 	},
 }
 
+var addGopTests = []struct {
+	desc    string
+	in      string
+	version string
+	out     string
+}{
+	{
+		`module_only`,
+		`module m
+		`,
+		`1.0`,
+		`module m
+		gop 1.0
+		`,
+	},
+	{
+		`module_before_require`,
+		`module m
+		require x.y/a v1.2.3
+		`,
+		`1.0`,
+		`module m
+		gop 1.0
+		require x.y/a v1.2.3
+		`,
+	},
+	{
+		`require_before_module`,
+		`require x.y/a v1.2.3
+		module example.com/inverted
+		`,
+		`1.0`,
+		`require x.y/a v1.2.3
+		module example.com/inverted
+		gop 1.0
+		`,
+	},
+	{
+		`require_only`,
+		`require x.y/a v1.2.3
+		`,
+		`1.0`,
+		`require x.y/a v1.2.3
+		gop 1.0
+		`,
+	},
+}
+
 var addExcludeTests = []struct {
 	desc    string
 	in      string
@@ -1454,6 +1502,16 @@ func TestAddGo(t *testing.T) {
 	}
 }
 
+func TestAddGop(t *testing.T) {
+	for _, tt := range addGopTests {
+		t.Run(tt.desc, func(t *testing.T) {
+			testEdit(t, tt.in, tt.out, true, func(f *File) error {
+				return f.AddGopStmt(tt.version)
+			})
+		})
+	}
+}
+
 func TestAddExclude(t *testing.T) {
 	for _, tt := range addExcludeTests {
 		t.Run(tt.desc, func(t *testing.T) {
@@ -1637,6 +1695,48 @@ func TestFixVersion(t *testing.T) {
 	}
 }
 
+var addParseExtTests = []struct {
+	desc    string
+	ext     string
+	want    string
+	wantErr string
+}{
+	{
+		"spx ok",
+		".spx",
+		".spx",
+		"",
+	},
+	{
+		"no ext",
+		"",
+		"",
+		"",
+	},
+	{
+		"not a ext",
+		"gmx",
+		"",
+		"ext \"gmx\" invalid: invalid ext format",
+	},
+}
+
+func TestParseExt(t *testing.T) {
+	for _, tt := range addParseExtTests {
+		t.Run(tt.desc, func(t *testing.T) {
+			ext, err := parseExt(&tt.ext)
+			if err != nil {
+				if err.Error() != tt.wantErr {
+					t.Fatalf("wanterr %s,but got %s", tt.wantErr, err)
+				}
+			}
+			if ext != tt.want {
+				t.Fatalf("want %s,but got %s", tt.want, ext)
+			}
+		})
+	}
+}
+
 var gopmod = `
 module spx
 
